(utilities-module)=
# AutoTrader Utilities Module
`from autotrader import utilities`

(utils-get-config)=
## Configuration Utilities
```{eval-rst}
.. autofunction:: autotrader.utilities.get_data_config
```




## YAML Utilities

### Read YAML
```{eval-rst}
.. autofunction:: autotrader.utilities.read_yaml
```


### Write YAML
```{eval-rst}
.. autofunction:: autotrader.utilities.write_yaml
```


### Get Broker Configuration 
```{eval-rst}
.. autofunction:: autotrader.utilities.get_broker_config
```

(utils-get-data-config)=
### Get Data Configuration 
```{eval-rst}
.. autofunction:: autotrader.utilities.get_data_config
```

### Unpickle Broker Instance 
```{eval-rst}
.. autofunction:: autotrader.utilities.unpickle_broker
```



## Watchlist Utilities
```{eval-rst}
.. autofunction:: autotrader.utilities.get_watchlist
```

(utils-trade-results)=
## TradeAnalysis Class
```{eval-rst}
.. autoclass:: autotrader.utilities.TradeAnalysis
   :members:
```


(utils-datastream)=
## DataStream Class
```{eval-rst}
.. autoclass:: autotrader.utilities.DataStream
   :members:
```
